@@ -34,7 +34,11 @@ void update_pidata(GtkWidget* w, gpointer data)
 {
  debug("%s:%d update_pidata()",__FILE__,__LINE__);
  INT i;
+#ifdef _MACHINE_64
+ INT idx = (INT)((INT64)data);
+#else
  INT idx = (INT)data;
+#endif
  strcpy(pidata.values[idx], gtk_entry_get_text(GTK_ENTRY(w)));
  for (i=0;i<pidata.n;i++)
  {
@@ -47,7 +51,11 @@ void update_pidata_combo(GtkWidget* w, gpointer data)
 {
  debug("%s:%d update_pidata_combo()",__FILE__,__LINE__);
  INT i;
+#ifdef _MACHINE_64
+ INT idx = (INT)((INT64)data);
+#else
  INT idx = (INT)data;
+#endif
  CHAR* ctext = gtk_entry_get_text(GTK_ENTRY(w));
  debug("Combo type is: %s\n", ctext);
  if (!strcmp(ctext,"exactly"))       pidata.types[idx] = DEL_TYPE_EXACTLY;
@@ -279,7 +287,11 @@ CHAR* insert_wizard(CHAR* tabname)
   gtk_widget_show(label);
   entry = gtk_entry_new();
   gtk_entry_set_max_length(GTK_ENTRY(entry), MAX_INSERT_STR_LENGTH);
+#ifdef _MACHINE_32
   gtk_signal_connect(GTK_OBJECT(entry), "changed", GTK_SIGNAL_FUNC(update_pidata),(gpointer)(i));
+#else
+  gtk_signal_connect(GTK_OBJECT(entry), "changed", GTK_SIGNAL_FUNC(update_pidata),(gpointer)((INT64)i));
+#endif
   gtk_table_attach(GTK_TABLE (table), entry, 1, 2, i, i+1,
 		      GTK_FILL,GTK_FILL, 0, 0);
   gtk_widget_show(entry);
@@ -369,7 +381,11 @@ CHAR* delete_wizard(CHAR* tabname)
   gtk_widget_show(label);
   entry = gtk_entry_new();
   gtk_entry_set_max_length(GTK_ENTRY(entry), MAX_INSERT_STR_LENGTH);
+#ifdef _MACHINE_32
   gtk_signal_connect(GTK_OBJECT(entry), "changed", GTK_SIGNAL_FUNC(update_pidata),(gpointer)(i));
+#else
+  gtk_signal_connect(GTK_OBJECT(entry), "changed", GTK_SIGNAL_FUNC(update_pidata),(gpointer)((INT64)i));
+#endif
   gtk_table_attach(GTK_TABLE (table), entry, 1, 2, i, i+1,
 		      GTK_FILL,GTK_FILL, 0, 0);
   gtk_widget_show(entry);
@@ -386,7 +402,11 @@ CHAR* delete_wizard(CHAR* tabname)
   g_list_free(list);
   gtk_table_attach(GTK_TABLE (table), combo, 2, 3, i, i+1,
 		      GTK_FILL,GTK_FILL, 0, 0);
+#ifdef _MACHINE_32
   gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry), "changed", GTK_SIGNAL_FUNC(update_pidata_combo),(gpointer)(i));
+#else
+  gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry), "changed", GTK_SIGNAL_FUNC(update_pidata_combo),(gpointer)((INT64)i));
+#endif
   gtk_widget_show(combo);
  }
  gtk_widget_show(table);
@@ -1208,7 +1228,11 @@ void init_wdata()
  wdata.tab   = wdata.ltab   = wdata.sav    = NULL;
 }
 
-
+void clean_vars()
+{
+ debug("%s:%d clean_vars()", __FILE__,__LINE__);
+ qptr = NULL;
+}
 
 CHAR* ctable_wizard()
 {
